/* automatically generated by rust-bindgen 0.71.1 */

pub const VIRTIO_MMIO_MAGIC_VALUE: u32 = 0;
pub const VIRTIO_MMIO_VERSION: u32 = 4;
pub const VIRTIO_MMIO_DEVICE_ID: u32 = 8;
pub const VIRTIO_MMIO_VENDOR_ID: u32 = 12;
pub const VIRTIO_MMIO_DEVICE_FEATURES: u32 = 16;
pub const VIRTIO_MMIO_DEVICE_FEATURES_SEL: u32 = 20;
pub const VIRTIO_MMIO_DRIVER_FEATURES: u32 = 32;
pub const VIRTIO_MMIO_DRIVER_FEATURES_SEL: u32 = 36;
pub const VIRTIO_MMIO_GUEST_PAGE_SIZE: u32 = 40;
pub const VIRTIO_MMIO_QUEUE_SEL: u32 = 48;
pub const VIRTIO_MMIO_QUEUE_NUM_MAX: u32 = 52;
pub const VIRTIO_MMIO_QUEUE_NUM: u32 = 56;
pub const VIRTIO_MMIO_QUEUE_ALIGN: u32 = 60;
pub const VIRTIO_MMIO_QUEUE_PFN: u32 = 64;
pub const VIRTIO_MMIO_QUEUE_READY: u32 = 68;
pub const VIRTIO_MMIO_QUEUE_NOTIFY: u32 = 80;
pub const VIRTIO_MMIO_INTERRUPT_STATUS: u32 = 96;
pub const VIRTIO_MMIO_INTERRUPT_ACK: u32 = 100;
pub const VIRTIO_MMIO_STATUS: u32 = 112;
pub const VIRTIO_MMIO_QUEUE_DESC_LOW: u32 = 128;
pub const VIRTIO_MMIO_QUEUE_DESC_HIGH: u32 = 132;
pub const VIRTIO_MMIO_QUEUE_AVAIL_LOW: u32 = 144;
pub const VIRTIO_MMIO_QUEUE_AVAIL_HIGH: u32 = 148;
pub const VIRTIO_MMIO_QUEUE_USED_LOW: u32 = 160;
pub const VIRTIO_MMIO_QUEUE_USED_HIGH: u32 = 164;
pub const VIRTIO_MMIO_SHM_SEL: u32 = 172;
pub const VIRTIO_MMIO_SHM_LEN_LOW: u32 = 176;
pub const VIRTIO_MMIO_SHM_LEN_HIGH: u32 = 180;
pub const VIRTIO_MMIO_SHM_BASE_LOW: u32 = 184;
pub const VIRTIO_MMIO_SHM_BASE_HIGH: u32 = 188;
pub const VIRTIO_MMIO_CONFIG_GENERATION: u32 = 252;
pub const VIRTIO_MMIO_CONFIG: u32 = 256;
pub const VIRTIO_MMIO_INT_VRING: u32 = 1;
pub const VIRTIO_MMIO_INT_CONFIG: u32 = 2;
